@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -90,7 +90,7 @@ sub _system_or_backtick {
         if ($opts->{capture}) {
             require Capture::Tiny;
             ($opts->{capture}[0], $opts->{capture}[1]) =
-                Capture::Tiny::capture($doit);
+                &Capture::Tiny::capture($doit);
         } else {
             $doit->();
         }
@@ -112,7 +112,7 @@ sub _system_or_backtick {
         if ($opts->{capture}) {
             require Capture::Tiny;
             ($opts->{capture}[0], $opts->{capture}[1]) =
-                Capture::Tiny::capture($doit);
+                &Capture::Tiny::capture($doit);
         } else {
             $doit->();
         }
@@ -200,7 +200,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.11 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-18.
+This document describes version 0.12 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
